# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.storage as windows_storage

Self = typing.TypeVar('Self')

@typing.final
class ApplicationDataManager_Static(winrt._winrt.IInspectable_Static):
    # Windows.Storage.ApplicationData Windows.Management.Core.ApplicationDataManager::CreateForPackageFamily(System.String)
    def create_for_package_family(cls, package_family_name: str, /) -> windows_storage.ApplicationData: ...

@typing.final
class ApplicationDataManager(winrt.system.Object, metaclass=ApplicationDataManager_Static):
    pass

